pub enum DataItem<'a, P>where
P: ToOwned,{
Str(&'a str),
Bytes(&'a [u8]),
Parsed(Cow<'a, P>),
}Variants
Str(&'a str)
Bytes(&'a [u8])
Parsed(Cow<'a, P>)
With parsed, we allow owned data since its likely compact and it may be necessary when we are unable to produce a reference to the primary-source data.