Type Alias MethodData

pub type MethodData<'a> = DataItem<'a, Method>;

Aliased Type

pub enum MethodData<'a> {
    Str(&'a str),
    Bytes(&'a [u8]),
    Parsed(Cow<'a, Method>),
}

Variants



Str(&'a str)



Bytes(&'a [u8])



Parsed(Cow<'a, Method>)

With parsed, we allow owned data since its likely compact and it may be necessary when we are unable to produce a reference to the primary-source data.