pub enum HeaderData<'a> {
Str(Box<dyn ExactSizeIterator<Item = (&'a str, &'a str)> + 'a>),
Bytes(Box<dyn ExactSizeIterator<Item = (&'a [u8], &'a [u8])> + 'a>),
Parsed(Box<dyn ExactSizeIterator<Item = (&'a HeaderName, &'a HeaderValue)> + 'a>),
}Expand description
Internals
We need dyn dispatch for the ExactSizeIterator contained here since we have no idea at time of usage what the actual type may be. We “could” use three generics for each possible contained concrete ExactSizeIterator however it would substantially pollute the api. We would need to encode some of the ExactSizeIterator Item into each usage site, see below.
fn provide_headers<'s, IS, IB, IP>(&'s self, dk: DataKinds) -> Option<HeaderData<'s>>
where IS: ExactSizeIterator<Item = (&'s str, &'s str)>,
IB: ExactSizeIterator<Item = (&'s [u8], &'s [u8])>,
IP: ExactSizeIterator<Item = (&'s ::http::HeaderName, &'s ::http::HeaderValue)>;
We tried to use a & dyn ExactSizeIterator<Item = (..)> here but the issue is on implementation we will be returning a reference to an ExactSizeIterator created on the stack (without bending over backwards).
Variants
Str(Box<dyn ExactSizeIterator<Item = (&'a str, &'a str)> + 'a>)
Bytes(Box<dyn ExactSizeIterator<Item = (&'a [u8], &'a [u8])> + 'a>)
Parsed(Box<dyn ExactSizeIterator<Item = (&'a HeaderName, &'a HeaderValue)> + 'a>)
Implementations